==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/content/schematics/cannon/SchematicannonMenu.java <==
package com.zurrtum.create.content.schematics.cannon;

import com.zurrtum.create.AllMenuTypes;
import com.zurrtum.create.foundation.gui.menu.MenuBase;
import net.minecraft.class_1263;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1735;
import net.minecraft.class_1799;

public class SchematicannonMenu extends MenuBase<SchematicannonBlockEntity> {

    public SchematicannonMenu(int id, class_1661 inv, SchematicannonBlockEntity be) {
        super(AllMenuTypes.SCHEMATICANNON, id, inv, be);
    }

    @Override
    protected void initAndReadInventory(SchematicannonBlockEntity contentHolder) {
    }

    @Override
    protected void addSlots() {
        int x = 0;
        int y = 0;

        method_7621(new MenuSlot(contentHolder.inventory, 0, x + 15, y + 65));
        method_7621(new MenuSlot(contentHolder.inventory, 1, x + 171, y + 65));
        method_7621(new MenuSlot(contentHolder.inventory, 2, x + 134, y + 19));
        method_7621(new MenuSlot(contentHolder.inventory, 3, x + 174, y + 19));
        method_7621(new MenuSlot(contentHolder.inventory, 4, x + 15, y + 19));

        addPlayerSlots(37, 161);
    }

    @Override
    protected void saveData(SchematicannonBlockEntity contentHolder) {
    }

    @Override
    public class_1799 method_7601(class_1657 playerIn, int index) {
        class_1735 clickedSlot = method_7611(index);
        if (!clickedSlot.method_7681())
            return class_1799.field_8037;
        class_1799 stack = clickedSlot.method_7677();

        if (index < 5) {
            method_7616(stack, 5, field_7761.size(), true);
        } else {
            if (method_7616(stack, 0, 1, false) || method_7616(stack, 2, 3, false) || method_7616(stack, 4, 5, false))
                ;
        }

        return class_1799.field_8037;
    }

    private static class MenuSlot extends class_1735 {
        public MenuSlot(class_1263 inventory, int index, int x, int y) {
            super(inventory, index, x, y);
        }

        @Override
        public class_1799 method_7671(int amount) {
            return super.method_7671(Math.min(field_7871.method_58350(method_7677()), amount));
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/schematics/cannon/SchematicannonMenu.java <==
package com.zurrtum.create.content.schematics.cannon;

import com.zurrtum.create.AllMenuTypes;
import com.zurrtum.create.foundation.gui.menu.MenuBase;
import com.zurrtum.create.foundation.gui.menu.MenuSlot;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1735;
import net.minecraft.class_1799;

public class SchematicannonMenu extends MenuBase<SchematicannonBlockEntity> {

    public SchematicannonMenu(int id, class_1661 inv, SchematicannonBlockEntity be) {
        super(AllMenuTypes.SCHEMATICANNON, id, inv, be);
    }

    @Override
    protected void initAndReadInventory(SchematicannonBlockEntity contentHolder) {
    }

    @Override
    protected void addSlots() {
        int x = 0;
        int y = 0;

        method_7621(new MenuSlot(contentHolder.inventory, 0, x + 15, y + 65));
        method_7621(new MenuSlot(contentHolder.inventory, 1, x + 171, y + 65));
        method_7621(new MenuSlot(contentHolder.inventory, 2, x + 134, y + 19));
        method_7621(new MenuSlot(contentHolder.inventory, 3, x + 174, y + 19));
        method_7621(new MenuSlot(contentHolder.inventory, 4, x + 15, y + 19));

        addPlayerSlots(37, 161);
    }

    @Override
    protected void saveData(SchematicannonBlockEntity contentHolder) {
    }

    @Override
    public class_1799 method_7601(class_1657 playerIn, int index) {
        class_1735 clickedSlot = method_7611(index);
        if (!clickedSlot.method_7681())
            return class_1799.field_8037;
        class_1799 stack = clickedSlot.method_7677();

        if (index < 5) {
            method_7616(stack, 5, field_7761.size(), true);
        } else {
            if (method_7616(stack, 0, 1, false) || method_7616(stack, 2, 3, false) || method_7616(stack, 4, 5, false))
                ;
        }

        return class_1799.field_8037;
    }
}
